# reticle

[![Testing Status](https://travis-ci.org/clintval/reticle.svg)](https://travis-ci.com/clintval/reticle)
[![codecov](https://codecov.io/gh/clintval/reticle/branch/master/graph/badge.svg)](https://codecov.io/gh/clintval/reticle)
[![MyPy Checked](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

Python 3.6+ library for submitting to AWS Batch interactively.

```python
❯ pip install reticle
```

Features:

- Submit Batch jobs